@@ -18,6 +18,17 @@ AnnotationHub <-
              localHub=getAnnotationHubOption("LOCAL"),
              ask=getAnnotationHubOption("ASK"))
 {
+
+    if ((cache == R_user_dir("AnnotationHub", which="cache")) && (Sys.getenv("ANNOTATION_HUB_CACHE")=="")){
+        olddefault = rappdirs::user_cache_dir(appname="AnnotationHub")
+        if (dir.exists(olddefault) && (length(list.files(olddefault)) != 0)){
+            stop(msg=paste0("DEFUNCT: As of AnnotationHub (>2.23.2), default caching location has changed.\n",
+                 "  Problematic cache: ", path.expand(olddefault), "\n",
+                 "  See https://bioconductor.org/packages/devel/bioc/vignettes/AnnotationHub/inst/doc/TroubleshootingTheCache.html#default-caching-location-update\n"))
+            cache = olddefault
+        }
+    }
+
     if (is.null(proxy)){
         connect <- suppressWarnings(tryCatch({
             readBin(hub, n=1L, what="raw")
