@@ -15,7 +15,7 @@
         setAnnotationHubOption("URL", opt)
     }
     if (is.null(getAnnotationHubOption("CACHE"))) {
-        path <- user_cache_dir(appname=.CACHE_ROOT)
+        path <- tools::R_user_dir(.CACHE_ROOT, which="cache")
         opt <- getOption("ANNOTATION_HUB_CACHE", path)
         opt <- Sys.getenv("ANNOTATION_HUB_CACHE", opt)
         setAnnotationHubOption("CACHE", opt)
@@ -38,4 +38,10 @@
         opt <- as.logical(opt)
         setAnnotationHubOption("LOCAL", opt)
     }
+    if (is.null(getAnnotationHubOption("ASK"))) {
+        opt <- getOption("ANNOTATION_HUB_ASK", interactive())
+        opt <- Sys.getenv("ANNOTATION_HUB_ASK", opt)
+        opt <- as.logical(opt)
+        setAnnotationHubOption("ASK", opt)
+    }
 }
